pub fn normalize(model: &mut SchemaModel, opts: &NormalizeOptions)Expand description
Filter and normalize the schema model based on options.
pub fn normalize(model: &mut SchemaModel, opts: &NormalizeOptions)Filter and normalize the schema model based on options.