pub fn transform_constraints(
model: &mut SchemaModel,
enable_foreign_keys: bool,
warnings: &mut Vec<Warning>,
)Expand description
Transform constraints on all tables in the schema model.
pub fn transform_constraints(
model: &mut SchemaModel,
enable_foreign_keys: bool,
warnings: &mut Vec<Warning>,
)Transform constraints on all tables in the schema model.